@@ -15,8 +15,8 @@
  */
 
 #include "Python.h"
-#include "basics.h"
 #include "mapcoder.h"
+#include "mapcode_legacy.h"
 #include <math.h>
 
 static char version_doc[] =
@@ -26,7 +26,7 @@ Returns the version of the Mapcode C library used by this module.\n";
 
 static PyObject *version(PyObject *self, PyObject *args)
 {
-    return Py_BuildValue("s", mapcode_cversion);
+    return Py_BuildValue("s", MAPCODE_C_VERSION);
 }
 
 
@@ -43,7 +43,7 @@ static PyObject *isvalid(PyObject *self, PyObject *args)
     if (!PyArg_ParseTuple(args, "s|i", &mapcode, &includes_territory))
        return NULL;
 
-    if (compareWithMapcodeFormat(mapcode, includes_territory ? 1 : 0) == 0) {
+    if (compareWithMapcodeFormatUtf8(mapcode) == 0) {
         return Py_True;
     } else {
         return Py_False;
@@ -55,9 +55,9 @@ static char decode_doc[] =
 "decode(mapcode, (territoryname)) -> (float, float)\n\
 \n\
 Decodes the provided string to latitude and longitude. Optionally\n\
-a territorycontext can be provided to disambiguate the mapcode.\n\
+a territory context can be provided to disambiguate the mapcode.\n\
 \n\
-Returns (nan,nan) when decoding failed.\n";
+Returns (nan, nan) when decoding failed.\n";
 
 static PyObject *decode(PyObject *self, PyObject *args)
 {
@@ -69,7 +69,7 @@ static PyObject *decode(PyObject *self, PyObject *args)
        return NULL;
 
     if (territoryname) {
-        territorycode = convertTerritoryIsoNameToCode(territoryname, 0);
+        territorycode = getTerritoryCode(territoryname, 0);
         if (territorycode < 0) {
             latitude = NAN;
             longitude = NAN;
@@ -78,7 +78,7 @@ static PyObject *decode(PyObject *self, PyObject *args)
     } else
         territorycode = 0;
 
-    if (decodeMapcodeToLatLon(&latitude, &longitude, mapcode, territorycode)) {
+    if (decodeMapcodeToLatLonUtf8(&latitude, &longitude, mapcode, territorycode, NULL)) {
         /* return nan,nan as error values */
         latitude = NAN;
         longitude = NAN;
@@ -91,10 +91,12 @@ static char encode_doc[] =
  "encode(latitude, longitude, (territoryname, (extra_digits))) -> [(string, string)] \n\
 \n\
 Encodes the given latitude, longitude to one or more mapcodes.\n\
-Returns a list of tuples that contain mapcode and territory context.\n\
+Returns a list of tuples that contain a mapcode and territory context.\n\
 \n\
 Optionally a territory context can be provided to generate a mapcode\n\
-in particular territory context.\n";
+in particular territory context.\n\
+Territory context AAA is a special case, which means Earth\n\
+(for international mapcodes).\n";
 
 static PyObject *encode(PyObject *self, PyObject *args)
 {
@@ -106,17 +108,13 @@ static PyObject *encode(PyObject *self, PyObject *args)
     if (!PyArg_ParseTuple(args, "dd|zi", &latitude, &longitude, &territoryname, &extra_digits))
        return NULL;
 
-    // printf("encode: args: %f, %f, %x, %i\n", latitude, longitude, territoryname, extra_digits);
-
     if (territoryname) {
-        territorycode = convertTerritoryIsoNameToCode(territoryname, 0);
+        territorycode = getTerritoryCode(territoryname, 0);
         if (territorycode < 0) {
             return PyList_New(0);
         }
     }
 
-    // printf("encode: territorystring: %s, code: %d\n", territoryname, territorycode);
-
     char *mapcode_results[2 * MAX_NR_OF_MAPCODE_RESULTS];
     int n = encodeLatLonToMapcodes_Deprecated(mapcode_results, latitude, longitude, territorycode, extra_digits);
     if (n > 0) {
@@ -133,13 +131,13 @@ static PyObject *encode(PyObject *self, PyObject *args)
 
 
 static char mapcode_doc[] =
-"Support for mapcodes. (See http://www.mapcode.org/).\n\
+"Mapcode support library (see http://www.mapcode.com).\n\
 \n\
 This module exports the following functions:\n\
-    version        Returns the version of the mapcode C-library used.\n\
-    isvalid        Verifies if the provided mapcode has the correct syntax.\n\
-    decode         Decodes a mapcode to latitude and longitude.\n\
-    encode         Encodes latitude and longitude to one or more mapcodes.\n";
+    version     Returns the version of the Mapcode C library.\n\
+    isvalid     Verifies if the provided mapcode has the correct syntax.\n\
+    decode      Decodes a mapcode to latitude and longitude.\n\
+    encode      Encodes latitude and longitude to one or more mapcodes.\n";
 
 /* The methods we expose in Python. */
 static PyMethodDef mapcode_methods[] = {
